Privacy Policy • Zeitgitter Server at ZEITGITTER_DOMAIN

- Home
- Terms of Service
- Privacy Policy
- Contact Information

# Privacy Policy

To provide this timestamping service in a trustworthy manner, the service irrevocably creates, maintains, and publishes a log file of its timestamping activity.

Therefore, the service records and publishes the following information permanently and irrevocably:

- The commit ID of all the commits you requested timestamping for, in the sequence it was processed. This sequence, together with the timestamps on the log, will also give insight into the timestamp returned.
  Not stored will be the IDs of the documents within your repository.

In order to maintain the service, we record the following information for up to 7 days, after which it will be deleted:

- For all requests: Time, IP address, and URL of the request.
- For branch timestamps: The ID of the timestamping branch's previous HEAD commit ("parent") and the SHA-1 hash of the GIT tree object. (In addition to time, IP address, URL, and commit ID).
- For tag timestamps: The name of the tag. (In addition to time, IP address, URL, and commit ID).